@@ -8,9 +8,9 @@ mod dataset;
 mod error;
 mod inference;
 mod model;
-mod optimal_retention;
 mod parameter_clipper;
-mod pre_training;
+mod parameter_initialization;
+mod simulation;
 #[cfg(test)]
 mod test_helpers;
 mod training;
@@ -22,8 +22,9 @@ pub use inference::{
     MemoryState, ModelEvaluation, NextStates, current_retrievability,
 };
 pub use model::FSRS;
-pub use optimal_retention::{
+pub use simulation::{
     CMRRTargetFn, Card, PostSchedulingFn, ReviewPriorityFn, RevlogEntry, RevlogReviewKind,
-    SimulationResult, SimulatorConfig, expected_workload, extract_simulator_config, simulate,
+    SimulationResult, SimulatorConfig, expected_workload, expected_workload_with_existing_cards,
+    extract_simulator_config, simulate,
 };
 pub use training::{CombinedProgressState, ComputeParametersInput};
