@@ -1,7 +1,7 @@
 #![deny(missing_docs)]
 #![allow(stable_features)]
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
-#![cfg_attr(not(any(feature = "std", test)), no_std)]
+#![no_std]
 #![cfg_attr(feature = "unstable-core-error", feature(error_in_core))]
 #![cfg_attr(
     feature = "unstable-provider-api",
@@ -272,6 +272,9 @@ extern crate alloc;
 #[cfg(feature = "alloc")]
 use alloc::{boxed::Box, string::String};
 
+#[cfg(feature = "std")]
+extern crate std;
+
 pub mod prelude {
     //! Traits and macros used by most projects. Add `use
     //! snafu::prelude::*` to your code to quickly get started with
@@ -440,6 +443,9 @@ mod fallback_error;
 #[doc(hidden)]
 pub use fallback_error::Error;
 
+#[cfg(any(feature = "alloc", test))]
+mod boxed_impls;
+
 /// Ensure a condition is true. If it is not, return from the function
 /// with an error.
 ///
@@ -1208,7 +1214,7 @@ pub trait ErrorCompat {
     ///
     /// To omit the current error and only traverse its sources,
     /// use `skip(1)`.
-    fn iter_chain(&self) -> ChainCompat
+    fn iter_chain(&self) -> ChainCompat<'_, '_>
     where
         Self: AsErrorSource,
     {
@@ -1225,16 +1231,6 @@ where
     }
 }
 
-#[cfg(any(feature = "alloc", test))]
-impl<E> ErrorCompat for Box<E>
-where
-    E: ErrorCompat,
-{
-    fn backtrace(&self) -> Option<&Backtrace> {
-        (**self).backtrace()
-    }
-}
-
 /// Converts the receiver into an [`Error`][] trait object, suitable
 /// for use in [`Error::source`][].
 ///
